@@ -4,6 +4,7 @@ from django.contrib import admin
 
 from .models import Category, Post, Blog
 
+
 class BlogAdmin(admin.ModelAdmin):
 	list_display=['blog','pub_date']
 	search_fields = ['blog']
@@ -11,13 +12,13 @@ class BlogAdmin(admin.ModelAdmin):
 	fields = ['blog']
 
 class PostAdmin(admin.ModelAdmin):
-	list_display=('title','category','pub_date')
-	search_fields=('title','category')
-	list_filter=['category','pub_date']
+	list_display=('title','blog','category','pub_date', 'publish',)
+	search_fields=('title','blog','category', 'publish')
+	list_filter=['category','blog','pub_date', 'publish']
 	fieldsets=[
-		(None, {'fields':['title','blog','category']}),
-		('Blog Entry',{'fields':['entry']}),
-#		('Date',{'fields':['pub_date'], 'classes':['collapse']}),
+		("Details", {'fields':['title','blog','category', 'publish','pub_date'], 'classes': ('grp-collapse grp-closed','collapse'),}),
+		('Blog Entry',{'fields':['entry'], 'classes': ('grp-collapse grp-closed','collapse'),}),
+
 		]
 
 class CategoryAdmin(admin.ModelAdmin):
@@ -25,6 +26,7 @@ class CategoryAdmin(admin.ModelAdmin):
 	search_fields= ['category',]
 	list_filter=['colour']
 
+
 admin.site.register(Post,PostAdmin)
 admin.site.register(Category,CategoryAdmin)
 admin.site.register(Blog, BlogAdmin)
\ No newline at end of file
